==> qtjambi-location-debuginfo-macos-5.15.17.jar: sources/QtJambiLocation/QPlaceSearchSuggestionReply_shell.h <==
#ifndef QPLACESEARCHSUGGESTIONREPLY_SHELL_H
#define QPLACESEARCHSUGGESTIONREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtLocation/qplacesearchsuggestionreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtLocation/qplacereply.h>
#include <QtJambi/RegistryAPI>


class QPlaceSearchSuggestionReply_shell : public QPlaceSearchSuggestionReply, public QtJambiShellInterface
{
public:
    QPlaceSearchSuggestionReply_shell(QObject* parent0 = nullptr);
    ~QPlaceSearchSuggestionReply_shell() override;

    void abort() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QPlaceReply::Type type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceSearchSuggestionReply_access : public QPlaceSearchSuggestionReply
{
    void __qt_setSuggestions_cref_QStringList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject suggestions0);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPLACESEARCHSUGGESTIONREPLY_SHELL_H

==> qtjambi-location-debuginfo-macos-5.15.20.jar: sources/QtJambiLocation/QPlaceSearchSuggestionReply_shell.h <==
#ifndef QPLACESEARCHSUGGESTIONREPLY_SHELL_H
#define QPLACESEARCHSUGGESTIONREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtLocation/qplacesearchsuggestionreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtLocation/qplacereply.h>
#include <QtJambi/RegistryAPI>


class QPlaceSearchSuggestionReply_shell : public QPlaceSearchSuggestionReply, public QtJambiShellInterface
{
public:
    QPlaceSearchSuggestionReply_shell(QObject* parent0 = nullptr);
    ~QPlaceSearchSuggestionReply_shell() override;

    void abort() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QPlaceReply::Type type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceSearchSuggestionReply_access : public QPlaceSearchSuggestionReply
{
    void __qt_setSuggestions_cref_QStringList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject suggestions0);
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPLACESEARCHSUGGESTIONREPLY_SHELL_H
